@@ -8,6 +8,7 @@
 #include <QNetworkReply>
 #include <QSignalMapper>
 #include <QLabel>
+#include "graphframe.h"
 
 namespace Ui {
     class StackedWindow;
@@ -30,11 +31,19 @@ protected:
 
 private slots:
     void setIcons(int mapping);
+	void addSnowGraph();
+	void addRainGraph();
 
 private:
     Ui::StackedWindow *ui;
     QSignalMapper* mapper;
     QNetworkAccessManager *manager;
+	QString* wfo;
+	QString* latlong;
+	QString* offset;
+	GraphFrame* snowFrame;
+	GraphFrame* rainFrame;
+
     void colorize(QLabel* label);
 };
 
